import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
var _excluded = ["type", "design", "color", "link", "href"],
    _excluded2 = ["type", "design", "color", "alignment", "link", "href"];
import { forwardRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Button from './Button';
import ButtonIcon from './ButtonIcon';
import ButtonSpinnerIcon from './buttonSpinnerIcon';
import { createClasses, CLASS, COLORS, DESIGNS, ALIGNMENT, ICON_POSITIONS, GROUP_POSITIONS, MODIFIERS, OWN_PROPS, SIZES, TYPES, SHAPES, TYPES_CONVERSION } from './config';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var CLASSES = createClasses([].concat(COLORS, Object.values(DESIGNS), Object.values(ALIGNMENT), MODIFIERS, Object.values(SIZES), ['empty']));
/**
 * Get props cleaning out AtomButton own props
 * @param  {Object} props
 * @return {Object}
 */

var cleanProps = function cleanProps(props) {
  var newProps = _extends({}, props);

  OWN_PROPS.forEach(function (key) {
    return delete newProps[key];
  });
  return newProps;
};
/**
 * Get modifiers to apply according to props
 * @param  {Object} props
 * @return {Array<String>}
 */


var getModifiers = function getModifiers(props) {
  return Object.keys(props).filter(function (name) {
    return props[name] && MODIFIERS.includes(name);
  });
};

function deprecated(validator, callback) {
  if (callback === void 0) {
    callback = function callback(props, propName, componentName) {
      var deprecatedMessage = "The prop " + '\x1b[32m' + propName + "\x1B[39m" + " is DEPRECATED on " + '\x1b[32m' + componentName + "\x1B[39m" + ".";
      console.warn(deprecatedMessage); // eslint-disable-line
    };
  }

  return function deprecated(props, propName, componentName) {
    for (var _len = arguments.length, rest = new Array(_len > 3 ? _len - 3 : 0), _key = 3; _key < _len; _key++) {
      rest[_key - 3] = arguments[_key];
    }

    if (props[propName] != null && process.env.NODE_ENV === 'development') {
      callback.apply(void 0, [props, propName, componentName].concat(rest));
    }

    return validator.apply(void 0, [props, propName, componentName].concat(rest));
  };
}

var typeConversion = function typeConversion(_ref) {
  var type = _ref.type,
      design = _ref.design,
      color = _ref.color,
      link = _ref.link,
      href = _ref.href,
      other = _objectWithoutPropertiesLoose(_ref, _excluded);

  var result = _extends({
    design: design,
    color: color,
    link: link,
    href: href
  }, other);

  switch (type) {
    case 'primary':
      result.color = color || 'primary';
      result.design = design || (link || href ? DESIGNS.LINK : DESIGNS.SOLID);
      break;

    case 'accent':
      result.color = color || 'accent';
      result.design = design || (link || href ? DESIGNS.LINK : DESIGNS.SOLID);
      break;

    case 'secondary':
      result.color = color || 'primary';
      result.design = design || (link || href ? DESIGNS.LINK : DESIGNS.OUTLINE);
      break;

    case 'tertiary':
      result.color = color || 'primary';
      result.design = design || (link || href ? DESIGNS.LINK : DESIGNS.FLAT);
      break;

    default:
      result.type = type;
      result.color = color || 'primary';
      break;
  }

  return result;
};

var getPropsWithDefaultValues = function getPropsWithDefaultValues(_ref2) {
  var type = _ref2.type,
      design = _ref2.design,
      color = _ref2.color,
      alignment = _ref2.alignment,
      link = _ref2.link,
      href = _ref2.href,
      other = _objectWithoutPropertiesLoose(_ref2, _excluded2);

  return _extends({}, other, {
    link: link,
    type: type,
    design: design || (link || href ? DESIGNS.LINK : DESIGNS.SOLID),
    color: color || 'colors',
    alignment: alignment || ALIGNMENT.CENTER
  });
};

var AtomButton = /*#__PURE__*/forwardRef(function (props, ref) {
  var _cx, _cx2;

  var _getPropsWithDefaultV = getPropsWithDefaultValues(typeConversion(props)),
      alignment = _getPropsWithDefaultV.alignment,
      className = _getPropsWithDefaultV.className,
      children = _getPropsWithDefaultV.children,
      color = _getPropsWithDefaultV.color,
      design = _getPropsWithDefaultV.design,
      disabled = _getPropsWithDefaultV.disabled,
      isLoading = _getPropsWithDefaultV.isLoading,
      focused = _getPropsWithDefaultV.focused,
      groupPosition = _getPropsWithDefaultV.groupPosition,
      link = _getPropsWithDefaultV.link,
      leftIcon = _getPropsWithDefaultV.leftIcon,
      loadingText = _getPropsWithDefaultV.loadingText,
      _getPropsWithDefaultV2 = _getPropsWithDefaultV.loader,
      loader = _getPropsWithDefaultV2 === void 0 ? /*#__PURE__*/_jsx(ButtonSpinnerIcon, {}) : _getPropsWithDefaultV2,
      rightIcon = _getPropsWithDefaultV.rightIcon,
      size = _getPropsWithDefaultV.size,
      title = _getPropsWithDefaultV.title,
      type = _getPropsWithDefaultV.type,
      shape = _getPropsWithDefaultV.shape,
      isFitted = _getPropsWithDefaultV.isFitted,
      selected = _getPropsWithDefaultV.selected;

  var classNames = cx(CLASS, CLASSES[color], CLASSES[design], alignment && CLASSES[alignment], groupPosition && CLASS + "-group " + CLASS + "-group--" + groupPosition, groupPosition && focused && CLASS + "-group--focused", groupPosition && selected && CLASS + "-group--selected", size && CLASSES[size], getModifiers(_extends({}, props, {
    disabled: disabled || isLoading
  })).map(function (key) {
    return CLASSES[key];
  }), !children && CLASSES.empty, (_cx = {}, _cx[CLASS + "--" + shape] = Object.values(SHAPES).includes(shape), _cx), (_cx2 = {}, _cx2[CLASS + "--loading"] = isLoading, _cx2[CLASS + "--fitted"] = isFitted, _cx2), className);
  var newProps = cleanProps(props);
  return /*#__PURE__*/_jsx(Button, _extends({}, newProps, {
    type: type,
    link: link,
    className: classNames,
    title: title,
    disabled: disabled || isLoading,
    forwardingRef: ref,
    children: /*#__PURE__*/_jsx("span", {
      className: CLASS + "-inner",
      children: isLoading ? /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsx(ButtonIcon, {
          position: loadingText ? ICON_POSITIONS.LEFT : ICON_POSITIONS.CENTER,
          size: size,
          children: loader
        }), children && loadingText ? loadingText : /*#__PURE__*/_jsx("span", {
          className: CLASS + "-text",
          children: children
        })]
      }) : /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsx(ButtonIcon, {
          position: ICON_POSITIONS.LEFT,
          size: size,
          children: leftIcon
        }), leftIcon || rightIcon ? /*#__PURE__*/_jsx("span", {
          className: CLASS + "-text",
          children: children
        }) : children, /*#__PURE__*/_jsx(ButtonIcon, {
          position: ICON_POSITIONS.RIGHT,
          size: size,
          children: rightIcon
        })]
      })
    })
  }));
});
AtomButton.displayName = 'AtomButton';
export default AtomButton;
export { GROUP_POSITIONS as atomButtonGroupPositions };
export { COLORS as atomButtonColors };
export { DESIGNS as atomButtonDesigns };
export { SIZES as atomButtonSizes };
export { TYPES as atomButtonTypes };
export { ALIGNMENT as atomButtonAlignment };
export { SHAPES as atomButtonShapes };